@@ -7,10 +7,23 @@
 
 """Invenio module containing the theme for TU Wien."""
 
+from flask.config import Config
+
 from . import config
 from .views import create_blueprint
 
 
+class TUWConfig(Config):
+    """Override for the Flask config that evaluates the SITE_{API,UI}_URL proxies."""
+
+    def __getitem__(self, key):
+        value = super().__getitem__(key)
+        if key in ("SITE_UI_URL", "SITE_API_URL"):
+            value = str(value)
+
+        return value
+
+
 class InvenioThemeTUW:
     """Invenio-Theme-TUW extension."""
 
@@ -27,6 +40,13 @@ class InvenioThemeTUW:
         blueprint = create_blueprint(app)
         app.register_blueprint(blueprint)
 
+        @app.before_first_request
+        def patch_config():
+            # replace the app's config with our own override that evaluates
+            # the LocalProxy objects set for SITE_{API,UI}_URL by casting them
+            # into strings (which is their expected type)
+            app.config = TUWConfig(app.config.root_path, app.config)
+
         @app.before_first_request
         def register_bp_first():
             # since invenio-app-rdm currently (april 2021) doesn't offer an easy way of
