@@ -52,7 +52,7 @@ theme = WebpackThemeBundle(
                 "invenio-theme-tuw-tracking": "./js/invenio_theme_tuw/tracking/index.js",
                 "invenio-theme-tuw-mobilemenu": "./js/invenio_theme_tuw/mobilemenu/index.js",
                 "invenio-theme-tuw-pdf-preview": "./js/invenio_theme_tuw/pdf-preview/index.js",
-                "invenio-theme-tuw-tuwstones": "./less/invenio_theme_tuw/tuwstone.less"
+                "invenio-theme-tuw-tuwstones": "./less/invenio_theme_tuw/tuwstone.less",
             },
             "dependencies": {
                 "jquery": "^3.2.1",
